@@ -30,7 +30,7 @@ void usage(char *progname)
 int main(int argc, char **argv) 
 {
 	int fd, ret, opt, quiet=0, setbools = 0, *values;
-	unsigned len, i;
+	int i, len;
 	size_t data_size;
 	struct stat sb;
 	void *map, *data;
