@@ -193,6 +193,11 @@ int authenticate_via_pam( const struct passwd *pw ) {
     result = 1;  /* user authenticated OK! */
   }
 
+  /* Ask PAM to verify acct_mgmt */
+  if( PAM_SUCCESS != pam_acct_mgmt(pam_handle,0) ) {
+    result = 0;  /* user authenticated OK! */
+  }
+
   /* We're done with PAM.  Free `pam_handle'. */
   pam_end( pam_handle, PAM_SUCCESS );
  
