@@ -164,7 +164,6 @@ int match(const char *name, struct stat *sb, char **con)
 {
 	int ret;
 	const char *fullname = name;
-	const char *buf = name;
 
 	/* fullname will be the real file that gets labeled
 	 * name will be what is matched in the policy */
@@ -175,7 +174,6 @@ int match(const char *name, struct stat *sb, char **con)
 			return -1;
 		}
 		name += rootpathlen;
-		buf += rootpathlen;
 	}
 
 	if (excludeCtr > 0) {
@@ -190,7 +188,11 @@ int match(const char *name, struct stat *sb, char **con)
 		return -1;
 	}
 
-	return matchpathcon_index(buf, sb->st_mode, con);
+	if(rootpath != NULL && name[0]=='\0')
+		/* this is actually the root dir of the alt root */
+		return matchpathcon_index("/", sb->st_mode, con);
+	else
+		return matchpathcon_index(name, sb->st_mode, con);
 }
 
 void usage(const char * const name)
@@ -431,6 +433,10 @@ int main(int argc, char **argv)
 				exit(1);
 			}
 			fclose(policystream);
+
+			/* Only process the specified file_contexts file, not
+			   any .homedirs or .local files. */
+			set_matchpathcon_flags(MATCHPATHCON_BASEONLY);
 			
 			break;
 		}
